@@ -1,11 +1,10 @@
-use ockam_core::compat::vec::Vec;
 use ockam_core::{Message, Result};
 
 // TODO: this function can not mutate the data vector it is given, and
 // thus copies its contents when using the fallback parsing strategy.
 // Ideally fallback parsing could create a slice between the length
 // and a vector without needing to move any data.
-pub(crate) fn message<M: Message>(vec: &Vec<u8>) -> Result<M> {
+pub(crate) fn message<M: Message>(vec: &[u8]) -> Result<M> {
     M::decode(vec).or_else(|_| {
         trace!("Parsing payload without inner length...");
 
@@ -18,7 +17,7 @@ pub(crate) fn message<M: Message>(vec: &Vec<u8>) -> Result<M> {
         let mut new_v = vec![vec.len() as u8]; // FIXME: does not handle message sizes over 255
         trace!("New message length: {:?}", new_v);
 
-        new_v.append(&mut vec.clone());
+        new_v.append(&mut vec.to_vec());
         M::decode(&new_v)
     })
 }
